@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Outline.pm,v 1.4 2003/12/08 13:05:19 Administrator Exp $
+#   $Id: Outline.pm,v 1.5 2004/03/18 06:47:57 fredo Exp $
 #
 #=======================================================================
 
@@ -44,7 +44,7 @@ BEGIN {
 
     @ISA = qw(PDF::API2::Basic::PDF::Dict);
 
-    ( $VERSION ) = '$Revision: 1.4 $' =~ /Revision: (\S+)\s/; # $Date: 2003/12/08 13:05:19 $
+    ( $VERSION ) = '$Revision: 1.5 $' =~ /Revision: (\S+)\s/; # $Date: 2004/03/18 06:47:57 $
 
 }
 
@@ -253,7 +253,7 @@ sub dest {
         die "insufficient parameters to ->dest( page, -fitr => [] ) " unless(scalar @{$opts{-fitr}} == 4);
         $self->{Dest}=PDFArray($page,PDFName('FitR'),map {PDFNum($_)} @{$opts{-fitr}});
     } elsif(defined $opts{-xyz}) {
-        die "insufficient parameters to ->dest( page, -xyz => [] ) " unless(scalar @{$opts{-fitr}} == 3);
+        die "insufficient parameters to ->dest( page, -xyz => [] ) " unless(scalar @{$opts{-xyz}} == 3);
         $self->{Dest}=PDFArray($page,PDFName('XYZ'),map {PDFNum($_)} @{$opts{-xyz}});
     }
     return($self);
@@ -356,6 +356,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: Outline.pm,v $
+    Revision 1.5  2004/03/18 06:47:57  fredo
+    fixed yank/paste error in dest method with -xyz parameter
+
     Revision 1.4  2003/12/08 13:05:19  Administrator
     corrected to proper licencing statement
 
